################################################################################
# Some examples on how to use the gpbi function. 
#
# Source the function
source(file = "Labrune_et_al_supp_mat_1.r")
# 
# Example 1 : a constructed test dataset
test.data <- matrix(c(10,10,10,10, 0, 8,8,8,8, 0, 0, 10, 10, 10, 0, 5, 5, 10, 10, 0, 5, 5, 5, 5, 0, 0, 0 , 0, 5, 12), nrow=6, byrow=TRUE)
rownames(test.data) <- paste("site", 1:nrow(test.data))
colnames(test.data) <- paste("sp", 1:ncol(test.data))
test.data

# Using only site 1 as a reference, no details kept
gpbi(x = test.data, refs = 1)
# Using only site 1 as a reference, details of the computations kept
gpbi(x = test.data, refs = 1, details = TRUE)
# Using only sites 1 and 2 as reference, no details kept
gpbi(x = test.data, refs = 1:2)
# Using only sites 1 and 2 as reference, no details kept
gpbi(x = test.data, refs = 1:2, details = TRUE)


# Glenan dataset
# Source the function
source(file = "Labrune_et_al_supp_mat_1.r")
# Read the file
glenan <- read.table(file = "Labrune_et_al_supp_mat_2.txt")
# The 3 first columns of the data.frame contains 
#  Ref : 1 if the station is a reference, 0 otherwise
#  Group : a grouping of the stations as in figure 4
#  DistanceFromExtraction : the distance of the station from the extraction point
# The other columns contain species abundances
glenan.fauna <- glenan[-(1:3)]

glenan.gpbi <- gpbi(x = glenan.fauna, refs = glenan$Ref)
# use details = TRUE if you want the details

# Here we recreate Figure 4 
plot(x = glenan$DistanceFromExtraction, y = glenan.gpbi, type = 'n', xlab = "Distance from extraction", ylab = "GPBI", ylim = c(0.2, 1))
points(x = glenan$DistanceFromExtraction[glenan$Group == "Reference"], y = glenan.gpbi[glenan$Group == "Reference"], pch = 1)
points(x = glenan$DistanceFromExtraction[glenan$Group == "Potentially not affected"], y = glenan.gpbi[glenan$Group == "Potentially not affected"], pch = 0)
points(x = glenan$DistanceFromExtraction[glenan$Group == "Potentially affected"], y = glenan.gpbi[glenan$Group == "Potentially affected"], pch = 20)
legend(x = 3000, y = 0.6, legend = c("Reference", "Potentially not affected", "Potentially affected"), pch = c(1,0,20))
